==> Heinzelmann-7.19.003-PHP8.zip: Quellcode/legacy/modules/tickettemplate/locales/en.php <==
<?php
$__LANG['...Bitte w&auml;hlen Sie eine Vorlage aus'] = '...Please select a template';
$__LANG['1. Kategorie'] = '1. Category';
$__LANG['2. Kategorie'] = '2. Category';
$__LANG['Aufwand in min'] = 'Expense in min';
$__LANG['Ausf&uuml;hren am'] = 'Execute on';
$__LANG['Benutzer'] = 'User';
$__LANG['Beschreibung'] = 'Description';
$__LANG['Bitte w&auml;hlen Sie erst Kategorie 1'] = 'Please select Category 1 first';
$__LANG['Das Dokument wirklich loeschen?'] = 'Do you really want to delete the document?';
$__LANG['Das Dokument wirklich löschen?'] = 'Do you really want to delete the document?';
$__LANG['Datum ausw&auml;hlen'] = 'Select date';
$__LANG['Di'] = 'Tu';
$__LANG['Do'] = 'Th';
$__LANG['Dokumente'] = 'Documents';
$__LANG['Ein Ticket wurde geschlossen'] = 'A ticket was closed';
$__LANG['Ein neues Ticket wurde erstellt'] = 'A new ticket was created';
$__LANG['Einmaliger Termin'] = 'One-time date';
$__LANG['Erstellt am'] = 'Created on';
$__LANG['Erstellt von'] = 'Created by';
$__LANG['Es wurde kein Aufwand angegeben'] = 'No expense entered';
$__LANG['Es wurde kein Kontakt zugeordnet'] = 'No contact assigned';
$__LANG['Es wurde keine Kategorie selektiert'] = 'No category selected';
$__LANG['Es wurde keine Kurzbeschreibung angegeben (min. 4 Zeichen)'] = 'No short description entered (at least 4 characters)';
$__LANG['F&auml;llig am'] = 'Due on';
$__LANG['F&auml;lligkeitstermin'] = 'Due date';
$__LANG['Fehler'] = 'Error';
$__LANG['Fr'] = 'Fr';
$__LANG['Ger&auml;te'] = 'Devices';
$__LANG['Gruppe'] = 'Group';
$__LANG['Icon'] = 'Icon';
$__LANG['Interessierter Kreis: '] = 'Stakeholder:';
$__LANG['Kategorie'] = 'Category';
$__LANG['Kategorie 1'] = 'Category 1';
$__LANG['Kategorie 2'] = 'Category 2';
$__LANG['Kategorie ausw&auml;hlen'] = 'Select Category';
$__LANG['Kein gueltiger Faelligkeitstermin'] = 'No valid due date';
$__LANG['Keine Dokumente vorhanden'] = 'No documents';
$__LANG['Keine Gruppe ausgew&auml;hlt'] = 'No group selected';
$__LANG['Keine Supporter gefunden'] = 'No supporter found';
$__LANG['Keine Wiederholung'] = 'No repetition';
$__LANG['Kontakt'] = 'Contact';
$__LANG['Kontakt hinzuf&uuml;gen'] = 'Add Contact';
$__LANG['Kontakt: '] = 'Contact:';
$__LANG['Kurzbeschr.'] = 'Short descr.';
$__LANG['Kurzbeschreibung'] = 'Short description';
$__LANG['L&ouml;schen'] = 'Delete';
$__LANG['Letzte &Auml;nderung'] = 'Last Update';
$__LANG['Link'] = 'Link';
$__LANG['Mi'] = 'We';
$__LANG['Mo'] = 'Mo';
$__LANG['Monatlich'] = 'Monthly';
$__LANG['Neue Vorlage anlegen'] = 'Create new template';
$__LANG['Neue Vorlage erstellen'] = 'Create new template';
$__LANG['Neues Ticket anlegen'] = 'Create new ticket';
$__LANG['Neues Ticket aus Vorlage'] = 'New ticket from template';
$__LANG['Priorit&auml;t'] = 'Priority';
$__LANG['Referenzticket'] = 'Reference ticket';
$__LANG['Sa'] = 'Sa';
$__LANG['Schlie&szlig;en'] = 'Close';
$__LANG['So'] = 'Su';
$__LANG['Speichern'] = 'Save';
$__LANG['Startzeit um'] = 'Starting time at';
$__LANG['Status'] = 'Status';
$__LANG['Supporter'] = 'Supporter';
$__LANG['Supporter: '] = 'Supporter:';
$__LANG['T&auml;glich'] = 'Daily';
$__LANG['Thumbnail'] = 'Thumbnail';
$__LANG['TicketRef. ID'] = 'TicketRef. ID';
$__LANG['TicketReferenz'] = 'Ticket Reference';
$__LANG['Ticketvorlagen'] = 'Ticket template';
$__LANG['Uhr'] = 'o´clock';
$__LANG['Upload'] = 'Upload';
$__LANG['User-Prio.'] = 'User Prio.';
$__LANG['Vorlage'] = 'Template';
$__LANG['Vorlage bearbeiten'] = 'Edit template';
$__LANG['Vorlage wirklich entfernen?'] = 'Delete template anyway?';
$__LANG['Vorlage(n)'] = 'Template(s)';
$__LANG['W&ouml;chentlich'] = 'Weekly';
$__LANG['Wiederholen am'] = 'Repeat on';
$__LANG['Wiederholungen'] = 'Repeats';
$__LANG['Wollen Sie die Vorlage wirklich wechseln?\n!!!Achtung!!! Damit gehen alle eingetragenen Daten verloren.'] = 'Do you really want to change the template?\n!!!Attention!!! All data will be lost.';
$__LANG['Zur&uuml;ck'] = 'Back';
$__LANG['ten Tag des Monats'] = '. day of month';
$__LANG['gefunden'] = 'found';
$__LANG['J&auml;hrlich'] = 'Yearly';
$__LANG['Im Monat'] = 'Of the month';
$__LANG['Januar'] = 'January';
$__LANG['Februar'] = 'February';
$__LANG['M&auml;rz'] = 'March';
$__LANG['April'] = 'April';
$__LANG['Mai'] = 'May';
$__LANG['Juni'] = 'June';
$__LANG['Juli'] = 'July';
$__LANG['August'] = 'August';
$__LANG['September'] = 'September';
$__LANG['Oktober'] = 'October';
$__LANG['November'] = 'November';
$__LANG['Dezember'] = 'December';
$__LANG['Kopieren'] = 'Copy';
$__LANG['L&ouml;sung bis'] = 'Solution date';
$__LANG['Jeden'] = 'Each';
$__LANG['Alle '] = 'All';
$__LANG['ten'] = 'ten';
$__LANG['Nächste Ausführung: '] = 'Next Processing:';
$__LANG['Ticket aus Vorlage'] = 'Ticket from template';
$__LANG['Masterticket zuweisen'] = 'Add Masterticket';
$__LANG[' Ticketvorlagen'] = 'Ticket template';
$__LANG['Kein Kontakt angegeben'] = 'No contact entered';
$__LANG['Geräte hinzufügen'] = 'Add device';
$__LANG['Auswahl l&ouml;schen'] = 'Delete selection';
$__LANG['Produktname'] = 'Product name';
$__LANG['Type'] = 'Type';
$__LANG['Build-Nr.'] = 'Build No.';
$__LANG['Verkäufer'] = 'Vendor';
$__LANG['Sprache'] = 'Language';
$__LANG['Install.-Datum'] = 'Install Date';
$__LANG['URL'] = 'URL';
$__LANG['Datei'] = 'File';
$__LANG['Es wurde keine Benutzergruppe selektiert'] = 'No user group was selected';
$__LANG['Kontakt wurde geändert'] = 'Contact has been changed';
$__LANG['Wählen Sie'] = 'Please select';
$__LANG['Gruppen gewählt'] = 'Groups selected';
$__LANG['Supporter gewählt'] = 'Supporter selected';
$__LANG['Alle X Tage'] = 'Every X days';
$__LANG['Vorlage wählbar für Gruppen'] = 'Template selectable for groups';
$__LANG['Alle Gruppen'] = 'All groups';
$__LANG['Wiederholen alle'] = 'Repeat every';
$__LANG['Tage'] = 'Days';
$__LANG['Nächste Ausführung am'] = 'Next Run on';
$__LANG['Bitte geben sie die Uhrzeit in einem gültigen Format (HH:MM o. HHMM) an.'] = 'Please enter the time in a valid format (HH:MM. or HHMM).';
$__LANG['Dateigr&ouml;&szlig;e'] = 'Filesize';
$__LANG['Dateiname'] = 'Filename';
$__LANG['Schnellschuss'] = 'Close in one go';


$__LANG['Löschen'] = 'Delete';
$__LANG['Kontakt entfernen'] = 'Remove contact';
$__LANG['Wiederholung'] = 'Replay';
$__LANG['Ohne Wiederholung sind die Vorlagen bei der manuellen Ticketerstellung verfügbar.<br/>Wählen Sie hier die Gruppen, für deren Benutzer die Vorlage sichtbar sein soll.'] = 'Without repetition, the templates are available for manual ticket creation.<br/>Select the groups for whose users the template should be visible.';

$__LANG['Benutzerdefinierte Auswahllisten'] = 'User-defined selection lists';
$__LANG['Wiederholungsmodus'] = 'Repeat mode';
$__LANG['Kurzbeschreibung (Titel)'] = 'Short description (title)';
$__LANG['Titel der Vorlage'] = 'Title of template';
$__LANG['Fügen Sie der Vorlage einen Titel und eine Beschreibung hinzu.<br/>Diese werden in der Vorlagenauswahl angezeigt.'] = 'Add a title and description to the template.<br/>They will be displayed in the template selection';
$__LANG['Beschreibung der Vorlage'] = 'Description of template';
$__LANG['Das Ticket <strong>%s</strong> wurde mit der TicketID <strong>#%u</strong> angelegt.'] = 'Ticket <strong>%s</strong was created with ticket ID <strong>#%u</strong.';
$__LANG['Ein Benutzer hat ein Dokument angef&uuml;gt.'] = 'A user has added a document';

$__LANG['Zeige _MENU_ Einträge'] = 'Show _MENU_ entries';
$__LANG['Keine Einträge gefunden'] = 'No entries found';
$__LANG['Einträge _START_ bis _END_ (von _TOTAL_)'] = 'Entries _START_ to _END_ (from _TOTAL_)';
$__LANG['- gefiltert aus _MAX_ Einträgen'] = '- filtered from _MAX_ entries';

$__LANG['Es wurde keine Kurzbeschreibung angegeben(min. 4 Zeichen)'] = 'There is no short descrition (at least 4 characters)';
$__LANG['Für die Vorlage wurde kein Titel angegeben'] = 'Please enter a titel for this template';

$__LANG['Titel der Ticketvorlage'] = 'Ticket template title';
$__LANG['Beschreibung der Ticketvorlage'] = 'Ticket template description';
$__LANG['Tickettitel'] = 'Ticket title';
$__LANG['Ticketbeschreibung'] = 'Ticket description';
$__LANG['Ticketverantwortlicher'] = 'Ticket manager';
$__LANG['Asset'] = 'Asset';
$__LANG['Dokument zufügen'] = 'Add document';
$__LANG['Dateien zum Upload hier hereinziehen oder klicken zur Dateiauswahl'] = 'Drag files here to upload or click to select files';
$__LANG['Hier bitte Ticketbeschreibung eintragen'] = 'Please enter ticket description here';

$__LANG['Letzten des Monats'] = 'Last of the month';

$__LANG['Reihenfolge in der Ticketauswahl']='Sequence in the ticket selection';
$__LANG['Je höher die Nummer, desto weiter vorne steht die Vorlage in der Auswahlliste im Ticket']='The higher the number, the further forward the template is in the selection list in the ticket.';
$__LANG['Ist keine Gruppe gewählt, ist die Vorlage für alle Benutzer die Tickets aus Vorlagen erstellen können sichtbar.'] = 'If no group is selected, the template is visible for all users who can create tickets from templates.';
$__LANG['Suchbegriff in Vorlagensuche'] = 'Search term in template search';

==> Heinzelmann-7.20.001-PHP8.zip: Quellcode/legacy/modules/tickettemplate/locales/en.php <==
<?php
$__LANG['...Bitte w&auml;hlen Sie eine Vorlage aus'] = '...Please select a template';
$__LANG['1. Kategorie'] = '1. Category';
$__LANG['2. Kategorie'] = '2. Category';
$__LANG['Aufwand in min'] = 'Expense in min';
$__LANG['Ausf&uuml;hren am'] = 'Execute on';
$__LANG['Benutzer'] = 'User';
$__LANG['Beschreibung'] = 'Description';
$__LANG['Bitte w&auml;hlen Sie erst Kategorie 1'] = 'Please select Category 1 first';
$__LANG['Das Dokument wirklich loeschen?'] = 'Do you really want to delete the document?';
$__LANG['Das Dokument wirklich löschen?'] = 'Do you really want to delete the document?';
$__LANG['Datum ausw&auml;hlen'] = 'Select date';
$__LANG['Di'] = 'Tu';
$__LANG['Do'] = 'Th';
$__LANG['Dokumente'] = 'Documents';
$__LANG['Ein Ticket wurde geschlossen'] = 'A ticket was closed';
$__LANG['Ein neues Ticket wurde erstellt'] = 'A new ticket was created';
$__LANG['Einmaliger Termin'] = 'One-time date';
$__LANG['Erstellt am'] = 'Created on';
$__LANG['Erstellt von'] = 'Created by';
$__LANG['Es wurde kein Aufwand angegeben'] = 'No expense entered';
$__LANG['Es wurde kein Kontakt zugeordnet'] = 'No contact assigned';
$__LANG['Es wurde keine Kategorie selektiert'] = 'No category selected';
$__LANG['Es wurde keine Kurzbeschreibung angegeben (min. 4 Zeichen)'] = 'No short description entered (at least 4 characters)';
$__LANG['F&auml;llig am'] = 'Due on';
$__LANG['F&auml;lligkeitstermin'] = 'Due date';
$__LANG['Fehler'] = 'Error';
$__LANG['Fr'] = 'Fr';
$__LANG['Ger&auml;te'] = 'Devices';
$__LANG['Gruppe'] = 'Group';
$__LANG['Icon'] = 'Icon';
$__LANG['Interessierter Kreis: '] = 'Stakeholder:';
$__LANG['Kategorie'] = 'Category';
$__LANG['Kategorie 1'] = 'Category 1';
$__LANG['Kategorie 2'] = 'Category 2';
$__LANG['Kategorie ausw&auml;hlen'] = 'Select Category';
$__LANG['Kein gueltiger Faelligkeitstermin'] = 'No valid due date';
$__LANG['Keine Dokumente vorhanden'] = 'No documents';
$__LANG['Keine Gruppe ausgew&auml;hlt'] = 'No group selected';
$__LANG['Keine Supporter gefunden'] = 'No supporter found';
$__LANG['Keine Wiederholung'] = 'No repetition';
$__LANG['Kontakt'] = 'Contact';
$__LANG['Kontakt hinzuf&uuml;gen'] = 'Add Contact';
$__LANG['Kontakt: '] = 'Contact:';
$__LANG['Kurzbeschr.'] = 'Short descr.';
$__LANG['Kurzbeschreibung'] = 'Short description';
$__LANG['L&ouml;schen'] = 'Delete';
$__LANG['Letzte &Auml;nderung'] = 'Last Update';
$__LANG['Link'] = 'Link';
$__LANG['Mi'] = 'We';
$__LANG['Mo'] = 'Mo';
$__LANG['Monatlich'] = 'Monthly';
$__LANG['Neue Vorlage anlegen'] = 'Create new template';
$__LANG['Neue Vorlage erstellen'] = 'Create new template';
$__LANG['Neues Ticket anlegen'] = 'Create new ticket';
$__LANG['Neues Ticket aus Vorlage'] = 'New ticket from template';
$__LANG['Priorit&auml;t'] = 'Priority';
$__LANG['Referenzticket'] = 'Reference ticket';
$__LANG['Sa'] = 'Sa';
$__LANG['Schlie&szlig;en'] = 'Close';
$__LANG['So'] = 'Su';
$__LANG['Speichern'] = 'Save';
$__LANG['Startzeit um'] = 'Starting time at';
$__LANG['Status'] = 'Status';
$__LANG['Supporter'] = 'Supporter';
$__LANG['Supporter: '] = 'Supporter:';
$__LANG['T&auml;glich'] = 'Daily';
$__LANG['Thumbnail'] = 'Thumbnail';
$__LANG['TicketRef. ID'] = 'TicketRef. ID';
$__LANG['TicketReferenz'] = 'Ticket Reference';
$__LANG['Ticketvorlagen'] = 'Ticket template';
$__LANG['Uhr'] = 'o´clock';
$__LANG['Upload'] = 'Upload';
$__LANG['User-Prio.'] = 'User Prio.';
$__LANG['Vorlage'] = 'Template';
$__LANG['Vorlage bearbeiten'] = 'Edit template';
$__LANG['Vorlage wirklich entfernen?'] = 'Delete template anyway?';
$__LANG['Vorlage(n)'] = 'Template(s)';
$__LANG['W&ouml;chentlich'] = 'Weekly';
$__LANG['Wiederholen am'] = 'Repeat on';
$__LANG['Wiederholungen'] = 'Repeats';
$__LANG['Wollen Sie die Vorlage wirklich wechseln?\n!!!Achtung!!! Damit gehen alle eingetragenen Daten verloren.'] = 'Do you really want to change the template?\n!!!Attention!!! All data will be lost.';
$__LANG['Zur&uuml;ck'] = 'Back';
$__LANG['ten Tag des Monats'] = '. day of month';
$__LANG['gefunden'] = 'found';
$__LANG['J&auml;hrlich'] = 'Yearly';
$__LANG['Im Monat'] = 'Of the month';
$__LANG['Januar'] = 'January';
$__LANG['Februar'] = 'February';
$__LANG['M&auml;rz'] = 'March';
$__LANG['April'] = 'April';
$__LANG['Mai'] = 'May';
$__LANG['Juni'] = 'June';
$__LANG['Juli'] = 'July';
$__LANG['August'] = 'August';
$__LANG['September'] = 'September';
$__LANG['Oktober'] = 'October';
$__LANG['November'] = 'November';
$__LANG['Dezember'] = 'December';
$__LANG['Kopieren'] = 'Copy';
$__LANG['L&ouml;sung bis'] = 'Solution date';
$__LANG['Jeden'] = 'Each';
$__LANG['Alle '] = 'All';
$__LANG['ten'] = 'ten';
$__LANG['Nächste Ausführung: '] = 'Next Processing:';
$__LANG['Ticket aus Vorlage'] = 'Ticket from template';
$__LANG['Masterticket zuweisen'] = 'Add Masterticket';
$__LANG[' Ticketvorlagen'] = 'Ticket template';
$__LANG['Kein Kontakt angegeben'] = 'No contact entered';
$__LANG['Geräte hinzufügen'] = 'Add device';
$__LANG['Auswahl l&ouml;schen'] = 'Delete selection';
$__LANG['Produktname'] = 'Product name';
$__LANG['Type'] = 'Type';
$__LANG['Build-Nr.'] = 'Build No.';
$__LANG['Verkäufer'] = 'Vendor';
$__LANG['Sprache'] = 'Language';
$__LANG['Install.-Datum'] = 'Install Date';
$__LANG['URL'] = 'URL';
$__LANG['Datei'] = 'File';
$__LANG['Es wurde keine Benutzergruppe selektiert'] = 'No user group was selected';
$__LANG['Kontakt wurde geändert'] = 'Contact has been changed';
$__LANG['Wählen Sie'] = 'Please select';
$__LANG['Gruppen gewählt'] = 'Groups selected';
$__LANG['Supporter gewählt'] = 'Supporter selected';
$__LANG['Alle X Tage'] = 'Every X days';
$__LANG['Vorlage wählbar für Gruppen'] = 'Template selectable for groups';
$__LANG['Alle Gruppen'] = 'All groups';
$__LANG['Wiederholen alle'] = 'Repeat every';
$__LANG['Tage'] = 'Days';
$__LANG['Nächste Ausführung am'] = 'Next Run on';
$__LANG['Bitte geben sie die Uhrzeit in einem gültigen Format (HH:MM o. HHMM) an.'] = 'Please enter the time in a valid format (HH:MM. or HHMM).';
$__LANG['Dateigr&ouml;&szlig;e'] = 'Filesize';
$__LANG['Dateiname'] = 'Filename';
$__LANG['Schnellschuss'] = 'Close in one go';


$__LANG['Löschen'] = 'Delete';
$__LANG['Kontakt entfernen'] = 'Remove contact';
$__LANG['Wiederholung'] = 'Replay';
$__LANG['Ohne Wiederholung sind die Vorlagen bei der manuellen Ticketerstellung verfügbar.<br/>Wählen Sie hier die Gruppen, für deren Benutzer die Vorlage sichtbar sein soll.'] = 'Without repetition, the templates are available for manual ticket creation.<br/>Select the groups for whose users the template should be visible.';

$__LANG['Benutzerdefinierte Auswahllisten'] = 'User-defined selection lists';
$__LANG['Wiederholungsmodus'] = 'Repeat mode';
$__LANG['Kurzbeschreibung (Titel)'] = 'Short description (title)';
$__LANG['Titel der Vorlage'] = 'Title of template';
$__LANG['Fügen Sie der Vorlage einen Titel und eine Beschreibung hinzu.<br/>Diese werden in der Vorlagenauswahl angezeigt.'] = 'Add a title and description to the template.<br/>They will be displayed in the template selection';
$__LANG['Beschreibung der Vorlage'] = 'Description of template';
$__LANG['Das Ticket <strong>%s</strong> wurde mit der TicketID <strong>#%u</strong> angelegt.'] = 'Ticket <strong>%s</strong was created with ticket ID <strong>#%u</strong.';
$__LANG['Ein Benutzer hat ein Dokument angef&uuml;gt.'] = 'A user has added a document';

$__LANG['Zeige _MENU_ Einträge'] = 'Show _MENU_ entries';
$__LANG['Keine Einträge gefunden'] = 'No entries found';
$__LANG['Einträge _START_ bis _END_ (von _TOTAL_)'] = 'Entries _START_ to _END_ (from _TOTAL_)';
$__LANG['- gefiltert aus _MAX_ Einträgen'] = '- filtered from _MAX_ entries';

$__LANG['Es wurde keine Kurzbeschreibung angegeben(min. 4 Zeichen)'] = 'There is no short descrition (at least 4 characters)';
$__LANG['Für die Vorlage wurde kein Titel angegeben'] = 'Please enter a titel for this template';

$__LANG['Titel der Ticketvorlage'] = 'Ticket template title';
$__LANG['Beschreibung der Ticketvorlage'] = 'Ticket template description';
$__LANG['Tickettitel'] = 'Ticket title';
$__LANG['Ticketbeschreibung'] = 'Ticket description';
$__LANG['Ticketverantwortlicher'] = 'Ticket manager';
$__LANG['Asset'] = 'Asset';
$__LANG['Dokument zufügen'] = 'Add document';
$__LANG['Dateien zum Upload hier hereinziehen oder klicken zur Dateiauswahl'] = 'Drag files here to upload or click to select files';
$__LANG['Hier bitte Ticketbeschreibung eintragen'] = 'Please enter ticket description here';

$__LANG['Letzten des Monats'] = 'Last of the month';

$__LANG['Reihenfolge in der Ticketauswahl']='Sequence in the ticket selection';
$__LANG['Je höher die Nummer, desto weiter vorne steht die Vorlage in der Auswahlliste im Ticket']='The higher the number, the further forward the template is in the selection list in the ticket.';
$__LANG['Ist keine Gruppe gewählt, ist die Vorlage für alle Benutzer die Tickets aus Vorlagen erstellen können sichtbar.'] = 'If no group is selected, the template is visible for all users who can create tickets from templates.';
$__LANG['Suchbegriff in Vorlagensuche'] = 'Search term in template search';

$__LANG['Sichtbarkeit'] = 'Visibility';
$__LANG['Vorlage aktiv'] = 'Template active';
$__LANG['Aktiv'] = 'Active';
$__LANG['Nur aktive Vorlagen stehen Benutzern zur Auswahl oder werden automatisch angelegt.'] = 'Only active templates are available for users to select or are created automatically.';
$__LANG['Ticketzuordnung'] = 'Ticket assignment';
$__LANG['Auswirkung'] = 'Impact';
$__LANG['Auswirkung wählen'] = 'Select impact';
$__LANG['Dringlichkeit'] = 'Urgency';
$__LANG['Dringlichkeit wählen'] = 'Select urgency';
$__LANG['Berechnete Priorität'] = 'Calculated priority';
